Expression class
Marker type to carry a code expression string in annotations.
The generator will unwrap Expr(code) and emit code as an
expression inside builder closures, instead of a string literal.
Constructors
- Expression(String code, {bool isString = false})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited